@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.80.2.2 2005/08/18 16:12:23 mbarbon Exp $
-## Copyright:   (c) 2000-2005 Mattia Barbon
+## RCS-ID:      $Id: Wx.pm,v 1.87 2006/04/16 15:11:07 mbarbon Exp $
+## Copyright:   (c) 2000-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.25_01';
+$VERSION = '0.49_01';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -90,30 +90,49 @@ sub _croak {
   goto &Carp::croak;
 }
 
-#
-# XSLoader/DynaLoader wrapper
-#
-sub wxPL_STATIC();
-sub wx_boot($$) {
-  local $ENV{PATH} = 'XXXALIENXXX' . $ENV{PATH} if $^O eq 'MSWin32';
-  if( $_[0] eq 'Wx' || !wxPL_STATIC ) {
-    if( $] < 5.006 ) {
-      require DynaLoader;
-      no strict 'refs';
-      push @{"$_[0]::ISA"}, 'DynaLoader';
-      $_[0]->bootstrap( $_[1] );
-    } else {
-      require XSLoader;
-      XSLoader::load( $_[0], $_[1] );
-    }
-  } else {
-    no strict 'refs';
-    my $t = $_[0]; $t =~ tr/:/_/;
-    &{"_boot_$t"}( $_[0], $_[1] );
-  }
+# Blech! (again...)
+# wxWidgets DLLs need to be installed in the same directory as Wx.dll,
+# but then LoadLibrary can't find them unless they are already loaded,
+# so we explicitly load them (on Win32 and wxWidgets 2.5.x+) just before
+# calling Wx::wx_boot. Finding the library requires determining the path
+# and the correct name
+use Wx::Mini;
+
+_start();
+
+our( $wx_path );
+
+sub _load_file {
+  Wx::wxVERSION() < 2.005 ? DynaLoader::dl_load_file( $_[0], 0 ) :
+                            Wx::_load_plugin( $_[0] );
 }
 
-wx_boot( 'Wx', $XS_VERSION );
+my( $load_fun, $unload_fun ) = ( \&_load_dll, \&_unload_dll );
+
+sub set_load_function { $load_fun = shift }
+sub set_end_function { $unload_fun = shift }
+
+sub load_dll {
+  return if $^O eq 'darwin' || Wx::wxVERSION() < 2.005;
+  goto &$load_fun;
+}
+
+sub unload_dll {
+  return if $^O eq 'darwin' || Wx::wxVERSION() < 2.005;
+  goto &$unload_fun;
+}
+
+END { unload_dll() }
+
+sub _unload_dll { }
+
+sub _load_dll {
+  local $ENV{PATH} = $wx_path . ';' . $ENV{PATH} if $wx_path;
+  return unless exists $Wx::dlls->{$_[0]};
+  my $dll = $Wx::dlls->{$_[0]};
+  $dll = $wx_path . '/' . $dll if $wx_path;
+  Wx::_load_file( $dll );
+}
 
 {
   _boot_Constant( 'Wx', $XS_VERSION );
@@ -139,6 +158,8 @@ no strict 'refs';
 use strict 'refs';
 *Wx::Size::x = \&Wx::Size::width;
 
+*Wx::Window::GetClientSizeWH = \&Wx::Window::GetClientSizeXY;
+
 Load();
 SetConstants();
 SetConstantsOnce();
@@ -182,12 +203,16 @@ package Wx::TreeItemId;
 
 use overload '<=>'      => \&tiid_spaceship,
              'bool'     => sub { $_[0]->IsOk },
+             '""'       => sub { $_[0] },
+             '0+'       => sub { $_[0] },
              'fallback' => 1;
 
 package Wx::Font;
 
 use overload '<=>'      => \&font_spaceship,
              'bool'     => sub { $_[0]->Ok },
+             '""'       => sub { $_[0] },
+             '0+'       => sub { $_[0] },
              'fallback' => 1;
 
 #
@@ -313,7 +338,7 @@ must be placed in the same directory as the executable file.
           <dependentAssembly>
               <assemblyIdentity
                   type="win32"
-                  name="Microsoft.Windows.Common-Controls"        
+                  name="Microsoft.Windows.Common-Controls"
                   version="6.0.0.0"
                   publicKeyToken="6595b64144ccf1df"
                   language="*"
