@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     25/11/2000
-## RCS-ID:      $Id: App.pm,v 1.15 2005/08/13 23:11:40 mbarbon Exp $
+## RCS-ID:      $Id: App.pm,v 1.16 2005/09/08 21:15:53 mbarbon Exp $
 ## Copyright:   (c) 2000-2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -34,9 +34,7 @@ sub new {
   $this->SetAppName( $_[0] ); # reasonable default for Wx::ConfigBase::Get
 
   my $ret = Wx::_App::Start( $this, $_[1] || $this->can( 'OnInit' ) );
-  Wx::_croak( 'OnInit must return a true return value' )
-    # why does OnInit always return 0 on Mac?
-    unless $Wx::_platform == 4 || $ret;
+  Wx::_croak( 'OnInit must return a true return value' ) unless $ret;
 
   $this;
 }
